| IssueTrackeR-package | R Documentation |
Manage a 'GitHub' problem using R: wrangle issues, labels and milestones. It includes functions for storing, prioritizing (sorting), displaying, adding, deleting, and selecting (filtering) issues based on qualitative and quantitative information. Issues (labels and milestones) are written in lists and categorized into the S3 class to be easily manipulated as datasets in R.
Maintainer: Tanguy Barthelemy tanguy.barthelemy@insee.fr [artist]
Authors:
Tanguy Barthelemy tanguy.barthelemy@insee.fr [artist]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.