Add elements to a vector.

append(x, values, after = length(x))

# S3 method for class 'IssuesTB'
append(x, values, after = nrow(x))

Arguments

x

the vector the values are to be appended to.

values

a IssueTB or a IssuesTB object.

after

a subscript, after which the values are to be appended.

Value

A vector containing the values in x with the elements of values appended after the specified element of x.

References

Becker RA, Chambers JM, Wilks AR (1988). The New S Language. Chapman and Hall/CRC, London. ISBN 053409192X.

Examples

issues_selector <- init_selector(
    source = "Local",
    file = file.path(
        system.file("data_issues", package = "IssueTrackeR"),
        "list_issues.yaml"
    )
)
all_issues <- get_issues(selector = issues_selector)
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/list_issues.yaml.
new_issues <- append(all_issues, all_issues)