Generic function to count the number of issues in a list of issues.

count_issues(x, verbose = TRUE)

# S3 method for class 'IssuesTB'
count_issues(x, verbose = TRUE)

# Default S3 method
count_issues(...)

Arguments

x

An object of class IssuesTB.

verbose

A logical value indicating whether to print additional information. Default is TRUE.

...

Currently not used.

Value

Integer. The number of issues.

Examples

all_issues <- get_issues(
    source = "local",
    dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
    dataset_name = "open_issues.yaml"
)
#> Looking into open_issues.yaml ...
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/open_issues.yaml.

count_issues(all_issues)
#> [1] 126