format_issues: Format the issue in a simpler format

View source: R/wrangling_dataset_issues.R

format_issuesR Documentation

Format the issue in a simpler format

Description

Format the issue in a simpler format

Usage

format_issues(raw_issues, raw_comments, verbose = TRUE)

Arguments

raw_issues

a gh_response object output from the function gh which contains all the data and metadata for GitHub issues.

raw_comments

a gh_response object output from the function gh which contains all the data and metadata for GitHub comments.

verbose

A logical value indicating whether to print additional information. Default is TRUE.

Value

a list representing an issue with simpler structure (with number, title, body and labels) of all issues.

Examples


## Not run: 
raw_issues <- gh::gh(
    repo = "rjdemetra",
    owner = "rjdverse",
    endpoint = "/repos/:owner/:repo/issues",
    .limit = Inf,
    .progress = FALSE
)
raw_comments <- gh::gh(
    repo = "rjdemetra",
    owner = "rjdverse",
    endpoint = "/repos/:owner/:repo/issues/comments",
    .limit = Inf,
    .progress = FALSE
)
all_issues <- format_issues(raw_issues = raw_issues,
                            raw_comments = raw_comments,
                            verbose = FALSE)

## End(Not run)


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.