format_labels: Format the label in a simpler format

View source: R/wrangling_dataset_labels.R

format_labelsR Documentation

Format the label in a simpler format

Description

Format the label in a simpler format

Usage

format_labels(raw_labels, verbose = TRUE)

Arguments

raw_labels

a gh_response object output from the function gh which contains all the data and metadata for GitHub labels.

verbose

A logical value indicating whether to print additional information. Default is TRUE.

Value

a list representing labels with simpler structure (with name, description, colour)

Examples


## Not run: 
# With labels
raw_labels <- gh::gh(
   repo = "rjdemetra",
   owner = "rjdverse",
   endpoint = "/repos/:owner/:repo/labels",
   .limit = Inf,
   .progress = FALSE
)
format_labels(raw_labels)

## End(Not run)


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.