Returns a list of repos.

get_all_repos(owner, public = TRUE, private = TRUE, verbose = TRUE)

Arguments

owner

Character string containing the owner name

public

Boolean. Should we include public repos? (Default TRUE)

private

Boolean. Should we include private repos? (Default TRUE)

verbose

A boolean indicating whether to print additional information. Default is TRUE.

Value

A string with the list of repo of a user or an organisation.

Examples

# \donttest{
get_all_repos("rjdverse")
#> Try to find all repositories from rjdverse...Error in gh::gh(endpoint = "/user/repos", .limit = Inf, visibility = "private",  : 
#>   GitHub API error (403): Resource not accessible by integration
#> ℹ Read more at
#>   <https://docs.github.com/rest/repos/repos#list-repositories-for-the-authenticated-user>
#> Error:  Weird message...
#> → Please contact the maintainer of the package with the error message:
#> GitHub API error (403): Resource not accessible by integration
#> ℹ Read more at
#>   <https://docs.github.com/rest/repos/repos#list-repositories-for-the-authenticated-user>
# }