Number of comments of an Issue or set of issues

get_nbr_comments(x)

# S3 method for class 'IssueTB'
get_nbr_comments(x)

# S3 method for class 'IssuesTB'
get_nbr_comments(x)

Arguments

x

An object of class IssueTB or IssuesTB.

Value

An integer or an integer vector with the number of comments of the different issues in x.

Examples

issues_selector <- init_selector(
    source = "Local",
    file = file.path(
        system.file("data_issues", package = "IssueTrackeR"),
        "list_issues.yaml"
    )
)

all_issues <- get_issues(selector = issues_selector)
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/list_issues.yaml.

get_nbr_comments(all_issues)
#>   [1]  2  0 10  0  2  1  0  0  0  0  1  0  0  0  1  0  0  0  0  1  1  3  0  1  5
#>  [26]  3  3  0  0  1  2  2  1  2  1 12  0  0  0  1  0  2  0  3  0  1  1  2  2  0
#>  [51]  3  0  0  0  4  0  0  0  1  1  3  1  0  0  0  0  2  0  1  4  2  1  0  3  0
#>  [76]  1  2  0  0  3  2  0  3  3  2  3  0  6  0  4  0  0  4  2  1  1  0  0  0  0
#> [101]  2  1  2  0  2  1  0  0  0  0  0  2  4  3  1  3  4  0  6  1  6  2  3  4  1
#> [126]  0  0  2  0  6  3  1  0  0  0  1  0  0  2  2  1  8  0  1  1  2  3  4  2  0
#> [151]  0  1  4  0  5  3  2  3  2  2  3  1  2  0  2  1  1  0  1  2  0  3  8  0  2
#> [176]  1  0  2  1  2  0  1  4  3  3  1  2  1  0  2  0  1  0  2  2  2  5  0  0  0
#> [201]  1  0  5 11  2  3  4  1  0  1  1  0  2  0  1  2  1  3  3  0  1  0  1  4  1
#> [226]  0  4  7  2  0  8  2  0  0  2  2  3  0  5  1  1  1  1  3  2  1  1  2  3  1
#> [251]  0  0  2  4  1  1  1  2  1  1  1  1  1  1  8  3  0  1  5  3  4  4  3  5  2
#> [276]  0  5  4  3  1  6  2  2  2  1  3
get_nbr_comments(all_issues[1L, ])
#> [1] 2