Generic function to filter issues with a given text pattern in the title, body, or comments of a GitHub Issue object or a collection of Issues.
with_text(x, ...)
# S3 method for class 'IssuesTB'
with_text(x, ..., in_title = TRUE, in_body = TRUE, in_comments = TRUE)An object of class IssuesTB.
Additional arguments passed to grepl(), such as pattern
and ignore.case.
Boolean. Does the function search for text in the title?
(Default TRUE)
Boolean. Does the function search for text in the body?
(Default TRUE)
Boolean. Does the function search for text in the
comments? (Default TRUE)
An object IssuesTB with issues that satisfy the condition.
issues_selector <- init_selector(
source = "Local",
file = file.path(
system.file("data_issues", package = "IssueTrackeR"),
"list_issues.yaml"
)
)
all_issues <- get_issues(selector = issues_selector)
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/list_issues.yaml.
with_text(all_issues, pattern = "Excel")
#> There are 12 issues.
#>
#>
#> ── Issue jdemetra/jdplus-main#924 ──
#>
#> Title: Feature request to edit the values of user-defined variables (regressors) in the
#> Text:
#> A nice feature in the JD+ GUI would be the ability to edit the values of user-defined variables (UDVs) in situ, rather than having to reimport CSV or other files containing the edited UDV values.
#>
#> Our set-up means it is somewhat tedious to update UDVs. Sometimes, we just want to quickly see what a series would look lik
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#888 ──
#>
#> Title: Is it possible to choose the value `(?)` in GUI output?
#> Text:
#> The aim of this issue is to find out whether, when I generate an excel output with the GUI, it's possible to choose the length of series which items ends with `(?)`.
#>
#> I will take the example of the forecasted series.
#>
#> In X13-RegARIMA, there are forecasts in the preprocessing part but only with `(?)` items and it's not
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#865 ──
#>
#> Title: `(frozen)` in SAI names
#> Text:
#> I just created a new WS with csv and Excel files.
#> When I try to read it from R, I get `(frozen)` in the name of the SA-Items:
#>
#> https://github.com/user-attachments/assets/28fffeb1-b58c-42d5-8219-c440d30248d9
#>
#> Here is the R code:
#>
#> ``` r
#> library("rjd3workspace")
#>
#> jws <- jws_open("~/tmp.xml")
#> jsap <- jws_sap(jws, 1L)
#> sap_
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#653 ──
#>
#> Title: Excel SA-Item names contain `\n` to separate sheet series
#> Text:
#> When we create a new SA-Item from an Excel file, the name of the series is automatically `sheet name\nseries name`.
#>
#> On the GUI, it appears with an arrow ▶:
#>
#> 
#>
#> But on the XML file:
#>
#> 
#> .
#> I always get the following error message:
#>
#> Can't generate output (Excel)
#> java.io.IOException: Cannot find spreadsheet writer for file 'C:\Test_JDemetra_plus\Test_JDemetra_3.2.2\CLV_1_AfterFirstB
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#197 ──
#>
#> Title: Drag and drop from Excel does not import decimal values
#> Text:
#> 
#>
#>
#> ── Issue jdemetra/jdplus-main#112 ──
#>
#> Title: JWSACruncher and parameters `fullseriesname` and `refreshall`
#> Text:
#> I tried the following parameters files an a workspace with data created by an Excel file and it has no effect. Are the parameters `fullseriesname` and `refreshall` suppose to work in the JWSACruncher? Am I doing something wrong?
#> ```
#> <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
#> <wsaConfig bundle="10000" cs
#> ...
#>