append: Vector Merging

View source: R/wrangling_issues.R

appendR Documentation

Vector Merging

Description

Add elements to a vector.

Usage

append(x, values, after = length(x))

## S3 method for class 'IssuesTB'
append(x, values, after = nrow(x))

Arguments

x

the vector the values are to be appended to.

values

a IssueTB or a IssuesTB object.

after

a subscript, after which the values are to be appended.

Value

A vector containing the values in x with the elements of values appended after the specified element of x.

References

Becker RA, Chambers JM, Wilks AR (1988). The New S Language. Chapman and Hall/CRC, London. ISBN 053409192X.

Examples

append(1:5, 0:1, after = 3)

IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.