Learn R Programming

IssueTrackeR (version 1.4.1)

append: Vector Merging

Description

Add elements to a vector.

Usage

append(x, values, after = length(x))

# S3 method for IssuesTB append(x, values, after = nrow(x))

Value

A vector containing the values in x with the elements of

values appended after the specified element of x.

Arguments

x

the vector the values are to be appended to.

values

a IssueTB or a IssuesTB object.

after

a subscript, after which the values are to be appended.

References

Becker RA, Chambers JM, Wilks AR (1988). The New S Language. Chapman and Hall/CRC, London. ISBN 053409192X.

Examples

Run this code
path <- system.file("data_issues", package = "IssueTrackeR")
open_issues <- get_issues(
    source = "local",
    dataset_dir = path,
    dataset_name = "open_issues.yaml"
)
closed_issues <- get_issues(
    source = "local",
    dataset_dir = path,
    dataset_name = "closed_issues.yaml"
)
new_issues <- append(open_issues, closed_issues)

Run the code above in your browser using DataLab