author_last_comment: Name of last commentator

View source: R/finding-objects.R

author_last_commentR Documentation

Name of last commentator

Description

Retrieve the name of the last commentator

Usage

author_last_comment(x)

## S3 method for class 'IssueTB'
author_last_comment(x)

## S3 method for class 'IssuesTB'
author_last_comment(x)

Arguments

x

An object of class IssueTB or IssuesTB.

Value

A string with the name of the last person which leaves a comment. If there is no comments, it returns an empty string.

Examples

all_issues <- get_issues(
    source = "local",
    dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
    dataset_name = "open_issues.yaml"
)
author_last_comment(all_issues)
author_last_comment(all_issues[1L, ])


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.