View source: R/finding-objects.R
| author_last_comment | R Documentation |
Retrieve the name of the last commentator
author_last_comment(x)
## S3 method for class 'IssueTB'
author_last_comment(x)
## S3 method for class 'IssuesTB'
author_last_comment(x)
x |
An object of class |
A string with the name of the last person which leaves a comment. If there is no comments, it returns an empty string.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
author_last_comment(all_issues)
author_last_comment(all_issues[1L, ])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.