Retrieve the name of the last commentator
author_last_comment(x, ...)
# S3 method for class 'IssueTB'
author_last_comment(x, verbose = TRUE, ...)
# S3 method for class 'IssuesTB'
author_last_comment(x, verbose = TRUE, ...)A string with the name of the last person which leaves a comment. If there is no comments, it returns an empty string.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
#> Looking into open_issues.yaml ...
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/open_issues.yaml.
author_last_comment(all_issues)
#> Try to retrieve comments from the list of issues.
#> [1] "Immurb" "" "charphi"
#> [4] "" "" "TanguyBarthelemy"
#> [7] "" "TanguyBarthelemy" ""
#> [10] "" "charphi" ""
#> [13] "" "TanguyBarthelemy" "TanguyBarthelemy"
#> [16] "OlesjaL" "" ""
#> [19] "" "TanguyBarthelemy" ""
#> [22] "Immurb" "" "charphi"
#> [25] "" "Immurb" "TanguyBarthelemy"
#> [28] "TanguyBarthelemy" "" ""
#> [31] "" "" ""
#> [34] "" "charphi" ""
#> [37] "" "" ""
#> [40] "palatej" "palatej" ""
#> [43] "AQLT" "" ""
#> [46] "" "AQLT" ""
#> [49] "TanguyBarthelemy" "" "AlessandroPiovani"
#> [52] "" "TanguyBarthelemy" ""
#> [55] "palatej" "palatej" ""
#> [58] "" "" "MichelleHedger"
#> [61] "annasmyk" "" ""
#> [64] "" "" ""
#> [67] "TanguyBarthelemy" "charphi" ""
#> [70] "" "" ""
#> [73] "" "" ""
#> [76] "a-s-russo" "" "TanguyBarthelemy"
#> [79] "Ciamman" "" ""
#> [82] "a-s-russo" "a-s-russo" "a-s-russo"
#> [85] "CyLuGh" "" "Immurb"
#> [88] "" "" "Immurb"
#> [91] "" "a-s-russo" ""
#> [94] "charphi" "Immurb" ""
#> [97] "" "" "a-s-russo"
#> [100] "palatej" "AQLT" ""
#> [103] "" "" "a-s-russo"
#> [106] "a-s-russo" "Immurb" ""
#> [109] "" "charphi" "a-s-russo"
#> [112] "charphi" "" "palatej"
#> [115] "" "" ""
#> [118] "a-s-russo" "m20l22" "charphi"
#> [121] "charphi" "" "charphi"
#> [124] "" "charphi" "AQLT"
#> [127] "" "charphi"
author_last_comment(all_issues[1L, ])
#> [1] "Immurb"