Learn R Programming

IssueTrackeR (version 1.5.0)

count_issues: Count the number of Issues

Description

Generic function to count the number of issues in a list of issues.

Usage

count_issues(x, ...)

# S3 method for IssuesTB count_issues(x, verbose = TRUE, ...)

# S3 method for default count_issues(...)

Value

Integer. The number of issues.

Arguments

x

An object of class IssuesTB.

...

Currently not used.

verbose

A logical value indicating whether to print additional information. Default is TRUE.

Examples

Run this code
all_issues <- get_issues(
    source = "local",
    dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
    dataset_name = "open_issues.yaml"
)

count_issues(all_issues)

Run the code above in your browser using DataLab