powered by
Generic function to count the number of issues in a list of issues.
count_issues(x, ...)# S3 method for IssuesTB count_issues(x, verbose = TRUE, ...)# S3 method for default count_issues(...)
# S3 method for IssuesTB count_issues(x, verbose = TRUE, ...)
# S3 method for default count_issues(...)
Integer. The number of issues.
An object of class IssuesTB.
IssuesTB
Currently not used.
A logical value indicating whether to print additional information. Default is TRUE.
TRUE
all_issues <- get_issues( source = "local", dataset_dir = system.file("data_issues", package = "IssueTrackeR"), dataset_name = "open_issues.yaml" ) count_issues(all_issues)
Run the code above in your browser using DataLab