get_all_repos: Retrieve all the visible repos from a user / an organisation

View source: R/wrangling_repo.R

get_all_reposR Documentation

Retrieve all the visible repos from a user / an organisation

Description

Returns a list of repos.

Usage

get_all_repos(owner, public = TRUE, private = TRUE, verbose = TRUE)

Arguments

owner

A character string specifying the GitHub owner (only taken into account if source is set to "online"). Defaults to the package option IssueTrackeR.owner.

public

Boolean. Should we include public repos? (Default TRUE)

private

Boolean. Should we include private repos? (Default TRUE)

verbose

A logical value indicating whether to print additional information. Default is TRUE.

Value

A string with the list of repo of a user or an organisation.

Examples


## Not run: 
get_all_repos("rjdverse")

## End(Not run)


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.