View source: R/finding-objects.R
| get_nbr_comments | R Documentation |
Number of comments of an Issue or set of issues
get_nbr_comments(x)
## S3 method for class 'IssueTB'
get_nbr_comments(x)
## S3 method for class 'IssuesTB'
get_nbr_comments(x)
x |
An object of class |
An integer or an integer vector with the number of comments of the
different issues in x.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
get_nbr_comments(all_issues)
get_nbr_comments(all_issues[1L, ])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.