Number of comments of an Issue or set of issues
get_nbr_comments(x)
# S3 method for class 'IssueTB'
get_nbr_comments(x)
# S3 method for class 'IssuesTB'
get_nbr_comments(x)An integer or an integer vector with the number of comments of the
different issues in x.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
#> Looking into open_issues.yaml ...
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/open_issues.yaml.
get_nbr_comments(all_issues)
#> [1] 0 0 1 0 1 0 0 3 0 0 2 2 1 12 0 0 0 1 0 0 0 3 0 1 1
#> [26] 2 0 0 0 0 0 0 1 0 0 0 0 1 4 0 3 0 0 0 3 0 3 0 6 0
#> [51] 4 0 4 2 0 0 0 2 1 0 0 0 0 0 4 4 0 0 0 0 0 0 0 8 0
#> [76] 3 4 0 0 1 2 2 1 0 2 0 0 1 0 2 0 1 2 0 0 0 2 2 5 0
#> [101] 0 0 5 4 1 0 0 1 2 1 0 4 0 0 0 1 2 2 1 0 8 0 1 2 0
#> [126] 5
get_nbr_comments(all_issues[1L, ])
#> [1] 0