Combines multiple selector objects into a single selector. Useful for fetching issues from multiple sources in one operation.
merge_selector(...)A merged SelectorTB object containing all elements from the input
selectors.
s1 <- init_selector(
source = "GitHub",
owner = "TanguyBarthelemy",
repo = "IssueTrackeR"
)
s2 <- init_selector(source = "GitHub", owner = "TractorTom", repo = NULL)
#> Try to find all repositories from TractorTom...Error in gh::gh(endpoint = "/user/repos", .limit = Inf, visibility = "private", :
#> GitHub API error (403): Resource not accessible by integration
#> ℹ Read more at
#> <https://docs.github.com/rest/repos/repos#list-repositories-for-the-authenticated-user>
#> Error: Weird message...
#> → Please contact the maintainer of the package with the error message:
#> GitHub API error (403): Resource not accessible by integration
#> ℹ Read more at
#> <https://docs.github.com/rest/repos/repos#list-repositories-for-the-authenticated-user>
merged <- merge_selector(s1, s2)
#> Error: object 's2' not found