plot: Plot an IssuesTB object

plot.IssuesTBR Documentation

Plot an IssuesTB object

Description

Visualize the evolution of an issue tracker backlog.

Two types of plots are available:

  • "historic": displays the distribution of open issues by age.

  • "created-closed": displays backlog size together with the numbers of newly created and newly closed issues.

Usage

## S3 method for class 'IssuesTB'
plot(x, type = c("historic", "created-closed"), n = 3L, ...)

Arguments

x

An object of class IssuesTB.

type

Character string indicating which plot to produce. Accepted values are "historic" and "created-closed". The default is "historic".

n

Integer specifying the number of age classes to display when type = "historic".

...

Currently ignored.

Details

When type = "historic", a stacked area chart is produced showing the number of open issues by age over time. This visualization highlights the evolution and aging of the backlog.

The first classes correspond to one-year intervals (0-1y, 1-2y, ..., (n-1)-ny) and the last class groups all issues older than n years.

When type = "created-closed", the total number of open issues is displayed together with the monthly numbers of newly created and newly closed issues. This visualization helps assess whether issue creation and resolution rates are balanced over time.

All statistics are aggregated monthly, from the month of the first issue creation to the current date.

Value

Invisibly returns x.

Examples

all_issues <- rbind(
    get_issues(
        source = "local",
        dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
        dataset_name = "open_issues.yaml"
    ),
    get_issues(
        source = "local",
        dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
        dataset_name = "closed_issues.yaml"
    )
)

plot(all_issues, type = "historic")
plot(all_issues, type = "created-closed")


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.