Display IssueTB and IssuesTB with formatted output in the console
# S3 method for class 'IssueTB'
print(x, ...)
# S3 method for class 'IssuesTB'
print(x, ...)
# S3 method for class 'summary.IssueTB'
print(x, ...)
# S3 method for class 'summary.IssuesTB'
print(x, ...)
# S3 method for class 'LabelsTB'
print(x, ...)
# S3 method for class 'summary.LabelsTB'
print(x, ...)invisibly (with invisible()) NULL.
This function displays an issue (IssueTB object) or a list of issues
(IssuesTB object) with a formatted output.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
#> Looking into open_issues.yaml ...
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/open_issues.yaml.
# Display one issue
print(all_issues[1, ])
#>
#> ── Issue jdemetra/jdplus-main#1039 ──
#>
#> Title: Older WS are read not correctly
#> Text:
#> I created a WS with the version **3.7.1** with 1 SA-Processing with 1 SA-Item with:
#>
#> - the series AirPassengers ([air.csv](https://github.com/user-attachments/files/30928390/air.csv))
#> - the specification:
#> - X13 RSA3
#> - 1 outliers (AO in 1956-08-01) in the estimation spec
#> - a basic span (series span) from 1949-01-0
#> ...
#>
# Display several issues
print(all_issues[1:10, ])
#> There are 10 issues.
#>
#> ── Issue jdemetra/jdplus-main#1039 ──
#>
#> Title: Older WS are read not correctly
#> Text:
#> I created a WS with the version **3.7.1** with 1 SA-Processing with 1 SA-Item with:
#>
#> - the series AirPassengers ([air.csv](https://github.com/user-attachments/files/30928390/air.csv))
#> - the specification:
#> - X13 RSA3
#> - 1 outliers (AO in 1956-08-01) in the estimation spec
#> - a basic span (series span) from 1949-01-0
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#1029 ──
#>
#> Title: Seasonal component in X11 spec : if set to NO, no info displayed in GUI
#> Text:
#> HI ,
#>
#> in v 3.8.0 if seasonal component is unticked in the X11 part of the spec
#>
#> No information is diplayed in GUI
#>
#> <img width="246" height="62" alt="Image" src="https://github.com/user-attachments/assets/a57354d6-256f-4bac-aff8-fa68720aee74" />
#>
#> the estimation appears as invalid
#>
#> <img width="647" height="40" alt="I
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#1023 ──
#>
#> Title: OpenSSF badge
#> Text:
#> I recently discovered the OpenSSF badge.
#>
#> I was wondering if it applied to JDemetra+. It’s a badge that recognises packages that follow open-source best practice.
#>
#> The link is https://www.bestpractices.dev/
#>
#> ── Issue jdemetra/jdplus-main#1006 ──
#>
#> Title: Benchmarking Results includes forecast observations beyond the input series
#> Text:
#> <img width="340" height="216" alt="Image" src="https://github.com/user-attachments/assets/cd77b619-d644-4d03-925e-6a858eeb3709" />
#>
#> While testing JDemetra+ 3.7.1, I noticed an unexpected behaviour in the **Benchmarking Results** output. The input series used in this example ends in **2025 Q1**. However, the table displ
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#1004 ──
#>
#> Title: Outlier type and position are missing in Matrix |> Outliers
#> Text:
#> Related to cosa-tsa-shop/UserSupport#10
#>
#> In the section Matrix |> Outliers (from a SA-Processing), the version 2 and 3 differs by their presentation:
#>
#> - In version 2 we observe a column by outliers with type, position, coeff and T-Stats
#> - In version 3 we observe 2 columns by outliers with coeffs and T-Stats
#>
#> Is it poss
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#987 ──
#>
#> Title: The variable `regression.td-ftest` is missing in JD+ output
#> Text:
#> I generate a `demetra_m` output using the graphical interface (version 3.7.1) and I notice that the `td-ftest` column (`regression.td-ftest` item) is completely empty.
#> Is this a connection error between the input and output?
#> However, in version 2 (I tested version 2.2.6), for the same specifications and the same series
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#962 ──
#>
#> Title: JDemetra+ doesn't import duplicated variables
#> Text:
#> If two variables have the same value, only the last one will be read.
#>
#> Here is an example in R:
#>
#> ``` r
#> library("rjd3workspace")
#> path_xml <- tempfile(fileext = ".xml")
#> writeLines(
#> text = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
#> <tsVariables xmlns="ec/tss.core">
#> <tsVariable name="VAR1">
#> <t
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#961 ──
#>
#> Title: Calendario - JDemetra V3
#> Text:
#> Buenos días.
#> En la versión 3 de JJDemetra+ intento cargar el calendario para Argentina creado por mi, pero no lo reconoce la aplicación. El calendario se encuentra en formato cfgx y podía agregarlo en las versiones 2.0. De no agregar en las versiones 3, ¿cuál sería la forma para agregar los calendarios particulares po
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#943 ──
#>
#> Title: Generating output only if the SAP is computed
#> Text:
#> I try to understand why the output generation wors with the GUI sometimes and sometimes not.
#>
#> In this issue, I will use the verbs "compute" and "estimate" to refer to the same thing: obtaining the results of the SA estimate for my series. But perhaps there is a fundamental difference between the two actions...
#>
#> ## Exam
#> ...
#>
#>
#> ── Issue jdemetra/jdplus-main#940 ──
#>
#> Title: How the GUI sort by specification?
#> Text:
#> In the GUI, it's possible to sort the SA-Item of a SA-Processing by **Reference spec**. But how is it handle?
#>
#> I notice (in this example) that this isn’t done by name and that the `^` and `v` keys aren’t used to reverse the direction.
#>
#> https://github.com/user-attachments/assets/c627e166-e28b-4de2-818f-821dd96c6b6c
# Display the summary of one issue
summary(all_issues[2, ])
#> ── Issue jdemetra/jdplus-main#1029 ──
#>
#> Labels: bug
#> State: 🟢 Open
#> Nb comments: 0
#>
#> Title: Seasonal component in X11 spec : if set to NO, no info displayed in GUI
#> Text:
#> HI ,
#>
#> in v 3.8.0 if seasonal component is unticked in the X11 part of the spec
#>
#> No information is diplayed in GUI
#>
#> <img width="246" height="62" alt="Image" src="https://github.com/user-attachments/assets/a57354d6-256f-4bac-aff8-fa68720aee74" />
#>
#> the estimation appears as invalid
#>
#> <img width="647" height="40" alt="Image" src="https://github.com/user-attachments/assets/26b7da59-8cbc-43a7-ae8d-2d396912681b" />
#>
#>
#>
#> Expected behaviour is that all X11 estimations of S (from B5 to D10) are set to 0 or 1...and everthing is displayed and estimated
#> it was the case in v2.2.4
#>
#>
#>
# Display the summary of
summary(all_issues[1:10, ])
#> There are 10 issues.
#> - jdemetra/jdplus-main#1039 🟢 Open
#> - jdemetra/jdplus-main#1029 🟢 Open
#> - jdemetra/jdplus-main#1023 🟢 Open
#> - jdemetra/jdplus-main#1006 🟢 Open
#> - jdemetra/jdplus-main#1004 🟢 Open
#> - jdemetra/jdplus-main#987 🟢 Open
#> - jdemetra/jdplus-main#962 🟢 Open
#> - jdemetra/jdplus-main#961 🟢 Open
#> - jdemetra/jdplus-main#943 🟢 Open
#> - jdemetra/jdplus-main#940 🟢 Open