| summary | R Documentation |
Compute a summary of an issue or a list of issues
## S3 method for class 'IssueTB'
summary(object, ...)
## S3 method for class 'IssuesTB'
summary(object, with_labels = FALSE, ...)
## S3 method for class 'LabelsTB'
summary(object, ...)
object |
a |
... |
Unused argument |
with_labels |
Boolean. Display the labels with the list of issues.
Default is |
This function compute the summary of an issue (IssueTB object) with
adding some information (number of comments, ...).
For a list of issues (IssuesTB object), it just summarise the
information with statistics by modalities.
invisibly (with invisible()) NULL.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
# Summarise one issue
summary(all_issues[1, ])
# Summarise several issues
summary(all_issues[1:10, ])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.