Compute a summary of an issue or a list of issues
# S3 method for class 'IssueTB'
summary(object, ...)
# S3 method for class 'IssuesTB'
summary(object, with_labels = FALSE, ...)
# S3 method for class 'LabelsTB'
summary(object, ...)invisibly (with invisible()) NULL.
This function compute the summary of an issue (IssueTB object) with
adding some information (number of comments, ...).
For a list of issues (IssuesTB object), it just summarise the
information with statistics by modalities.
issues_selector <- init_selector(
source = "Local",
file = file.path(
system.file("data_issues", package = "IssueTrackeR"),
"list_issues.yaml"
)
)
all_issues <- get_issues(selector = issues_selector)
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/list_issues.yaml.
# Summarise one issue
summary(all_issues[1, ])
#>
#> ── Issue jdemetra/jdplus-main#1058 ──
#>
#> Labels: bug
#> State: ✔ Completed
#> Nb comments: 2
#>
#> Title: Friedman Test function calls QS Test in SeasonalityTests
#> Text:
#> https://github.com/jdemetra/jdplus-main/blob/c91573b85827831899e58ee1c89a6a1cb8760a7e/jdplus-main-base/jdplus-sa-base-parent/jdplus-sa-base-api/src/main/java/jdplus/sa/base/api/diagnostics/SeasonalityTests.java#L58-L60
#>
#> Hi, I just noticed that in this file the friedmanTest function actually calls the QS test. I'm assuming that's a mistake.
#>
#> Comments:
#>
#> Comment n°1 by palatej:
#>
#> Yes. Of course. Thank you. I correct it immediately
#>
#> Comment n°2 by charphi:
#>
#> This bug has been fixed in https://github.com/jdemetra/jdplus-main/pull/1059
#>
# Summarise several issues
summary(all_issues[1:10, ])
#> There are 10 issues.
#> - jdemetra/jdplus-main#1058 ✔ Completed
#> - jdemetra/jdplus-main#1049 🟢 Open
#> - jdemetra/jdplus-main#1039 ✔ Completed
#> - jdemetra/jdplus-main#1029 🟢 Open
#> - jdemetra/jdplus-main#1028 ✔ Completed
#> - jdemetra/jdplus-main#1023 🟢 Open
#> - jdemetra/jdplus-main#1006 🟢 Open
#> - jdemetra/jdplus-main#1004 🟢 Open
#> - jdemetra/jdplus-main#1002 ✔ Completed
#> - jdemetra/jdplus-main#989 ✔ Completed