Compute a summary of an issue or a list of issues

# S3 method for class 'IssueTB'
summary(object, ...)

# S3 method for class 'IssuesTB'
summary(object, with_labels = FALSE, ...)

# S3 method for class 'LabelsTB'
summary(object, ...)

Arguments

object

a IssueTB or IssuesTB object.

...

Currently not used.

with_labels

Boolean. Display the labels with the list of issues. Default is FALSE.

Value

invisibly (with invisible()) NULL.

Details

This function compute the summary of an issue (IssueTB object) with adding some information (number of comments, ...). For a list of issues (IssuesTB object), it just summarise the information with statistics by modalities.

Examples

all_issues <- get_issues(
    source = "local",
    dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
    dataset_name = "open_issues.yaml"
)
#> Looking into open_issues.yaml ...
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/open_issues.yaml.

# Summarise one issue
summary(all_issues[1, ])
#> 
#> ── Issue jdemetra/jdplus-main#1039 ──
#> 
#> Labels: 
#> State: 🟢 Open
#> Nb comments: 1
#> 
#> Title: Older WS are read not correctly
#> Text:
#> I created a WS with the version **3.7.1** with 1 SA-Processing with 1 SA-Item with:
#> 
#> - the series AirPassengers ([air.csv](https://github.com/user-attachments/files/30928390/air.csv))
#> - the specification:
#>   - X13 RSA3
#>   - 1 outliers (AO in 1956-08-01) in the estimation spec
#>   - a basic span (series span) from 1949-01-01 in the reference spec
#> 
#> 
#> ## My problem
#> 
#> With the version **3.8.0** of JDemetra+, the outlier is not recognised.
#> 
#> 
#> ## Appendix contents
#> 
#> Here is my WS in version [3.7.1.zip](https://github.com/user-attachments/files/30928503/3.7.1.zip).
#> And I created a identical (in terms of series and specification) in version [3.8.0.zip](https://github.com/user-attachments/files/30928502/3.8.0.zip).
#> 
#> 
#> ## Comparison
#> 
#> To explore "more" I compared the SAProcessing.xml files. In the version **3.8.0**, there are added lines.
#> 
#> In the estimation spec:
#> 
#> ```
#> + "    <item name=\"frequency\">"
#> + "        <integer>12</integer>"
#> + "    </item>"
#> ```
#> ```
#> + "                            </item>"
#> + "                        </subset>"
#> + "                    </item>"
#> + "                    <item name=\"x11\">"
#> + "                        <subset>"
#> + "                            <item name=\"seasonalma\">"
#> + "<strings>"
#> + "    <items>Msr Msr Msr Msr Msr Msr Msr Msr Msr Msr Msr Msr</items>"
#> + "</strings>"
#> + "                            </item>"
#> + "                            <item name=\"fcasts\">"
#> + "<integer>-1</integer>"
#> ```
#> 
#> And the same lines in the result spec:
#> 
#> ```
#> + "    <item name=\"frequency\">"
#> + "        <integer>12</integer>"
#> + "    </item>"
#> ```
#> 
#> ```
#> + "                            </item>"
#> + "                        </subset>"
#> + "                    </item>"
#> + "                    <item name=\"x11\">"
#> + "                        <subset>"
#> + "                            <item name=\"seasonalma\">"
#> + "<strings>"
#> + "    <items>Msr Msr Msr Msr Msr Msr Msr Msr Msr Msr Msr Msr</items>"
#> + "</strings>"
#> + "                            </item>"
#> + "                            <item name=\"fcasts\">"
#> + "<integer>-1</integer>"
#> ```
#> 
#> 
#> ## Question
#> 
#> Is it an intended behaviour?
#> The changelog mentions that a new field `frequency` is added in the SA Specification but he doesn’t mention that this would break the WS’s backwards compatibility...
#> 
#> Thank you
#> 
#> Comments:
#>  
#> Comment n°1 by Immurb:
#> 
#> @palatej is it really necessary to remove all user pre-specified variables in https://github.com/palatej/jd3-main/blob/develop/jdplus-main-base/jdplus-x13-base-parent/jdplus-x13-base-api/src/main/java/jdplus/x13/base/api/regarima/RegArimaSpec.java#L128-L136 and TRAMO respectively?
#> Shouldn't they be independent from the frequency of the time series?
#>  

# Summarise several issues
summary(all_issues[1:10, ])
#> There are 10 issues. 
#> - jdemetra/jdplus-main#1039 🟢 Open 
#> - jdemetra/jdplus-main#1029 🟢 Open 
#> - jdemetra/jdplus-main#1023 🟢 Open 
#> - jdemetra/jdplus-main#1006 🟢 Open 
#> - jdemetra/jdplus-main#1004 🟢 Open 
#> - jdemetra/jdplus-main#987 🟢 Open 
#> - jdemetra/jdplus-main#962 🟢 Open 
#> - jdemetra/jdplus-main#961 🟢 Open 
#> - jdemetra/jdplus-main#943 🟢 Open 
#> - jdemetra/jdplus-main#940 🟢 Open