Learn R Programming

IssueTrackeR (version 1.4.1)

summary: Compute a summary of an issue or a list of issues

Description

Compute a summary of an issue or a list of issues

Usage

# S3 method for IssueTB
summary(object, ...)

# S3 method for IssuesTB summary(object, with_labels = FALSE, ...)

# S3 method for LabelsTB summary(object, ...)

Value

invisibly (with invisible()) NULL.

Arguments

object

a IssueTB or IssuesTB object.

...

Unused argument

with_labels

Boolean. Display the labels with the list of issues. Default is FALSE.

Details

This function compute the summary of an issue (IssueTB object) with adding some information (number of comments, ...). For a list of issues (IssuesTB object), it just summarise the information with statistics by modalities.

Examples

Run this code
all_issues <- get_issues(
    source = "local",
    dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
    dataset_name = "open_issues.yaml"
)

# Summarise one issue
summary(all_issues[1, ])

# Summarise several issues
summary(all_issues[1:10, ])

Run the code above in your browser using DataLab