unique-issues: Unique issues of an IssuesTB Object

unique-issuesR Documentation

Unique issues of an IssuesTB Object

Description

Keep only different issues from a IssuesTB Object

Usage

## S3 method for class 'IssuesTB'
unique(x, incomparables = FALSE, ...)

Arguments

x

An object of class IssuesTB

incomparables

a vector of values that cannot be compared. FALSE is a special value, meaning that all values can be compared, and may be the only value accepted for methods other than the default. It will be coerced internally to the same type as x.

...

arguments for particular methods.

Details

This method is consistent with base::unique(). For details about the generic function and its default methods, refer to the original documentation: https://stat.ethz.ch/R-manual/R-devel/library/base/html/unique.html

Value

An IssuesTB object containing only unique issues.

See Also

base::unique(), base::duplicated()


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.