Keep only different issues from a IssuesTB Object
# S3 method for class 'IssuesTB'
unique(x, incomparables = FALSE, ...)An object of class IssuesTB
a vector of values that cannot be compared.
FALSE is a special value, meaning that all values can be
compared, and may be the only value accepted for methods other than
the default. It will be coerced internally to the same type as
x.
arguments for particular methods.
An IssuesTB object containing only unique issues.
This method is consistent with base::unique(). For details about the
generic function and its default methods, refer to the original
documentation:
https://stat.ethz.ch/R-manual/R-devel/library/base/html/unique.html