Learn R Programming

IssueTrackeR (version 1.4.1)

unique-issues: Unique issues of an IssuesTB Object

Description

Keep only different issues from a IssuesTB Object

Usage

# S3 method for IssuesTB
unique(x, incomparables = FALSE, ...)

Value

An IssuesTB object containing only unique issues.

Arguments

x

An object of class IssuesTB.

incomparables

a vector of values that cannot be compared. FALSE is a special value, meaning that all values can be compared, and may be the only value accepted for methods other than the default. It will be coerced internally to the same type as x.

...

arguments for particular methods.

Details

This method is consistent with base::unique(). For details about the generic function and its default methods, refer to the original documentation: https://stat.ethz.ch/R-manual/R-devel/library/base/html/unique.html

See Also

Examples

Run this code
path <- system.file("data_issues", package = "IssueTrackeR")
open_issues <- get_issues(
    source = "local",
    dataset_dir = path,
    dataset_name = "open_issues.yaml"
)
new_issues <- unique(open_issues)

Run the code above in your browser using DataLab