View source: R/update_database.R
| update_database | R Documentation |
Update the different local database (issues, labels and milestones) with the online reference.
update_database(
dataset_dir = getOption("IssueTrackeR.dataset.dir"),
datasets_name = c(open = "open_issues.yaml", closed = "closed_issues.yaml", labels =
"list_labels.yaml", milestones = "list_milestones.yaml"),
verbose = TRUE,
...
)
dataset_dir |
A character string specifying the path which contains the
datasets (only taken into account if |
datasets_name |
A named character string of length 4, specifying the
names of the different datasets which will be written. The names
|
verbose |
A logical value indicating whether to print additional
information. Default is |
... |
Additional arguments for connecting to the GitHub repository:
|
invisibly (with invisible()) TRUE.
## Not run:
update_database(dataset_dir = tempdir())
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.