with_text: Check for text in GitHub Issues

View source: R/finding-objects.R

with_textR Documentation

Check for text in GitHub Issues

Description

Generic function to filter issues with a given text pattern in the title, body, or comments of a GitHub Issue object or a collection of Issues.

Usage

with_text(x, ...)

## S3 method for class 'IssuesTB'
with_text(x, ..., in_title = TRUE, in_body = TRUE, in_comments = TRUE)

Arguments

x

An object of class IssuesTB.

...

Additional arguments passed to grepl(), such as pattern and ignore.case.

in_title

Boolean. Does the function search for text in the title? (Default TRUE)

in_body

Boolean. Does the function search for text in the body? (Default TRUE)

in_comments

Boolean. Does the function search for text in the comments? (Default TRUE)

Value

An object IssuesTB with issues that satisfy the condition.

Examples

all_issues <- get_issues(
    source = "local",
    dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
    dataset_name = "open_issues.yaml"
)
with_text(all_issues, pattern = "Excel")


IssueTrackeR documentation built on June 21, 2026, 1:07 a.m.