View source: R/finding-objects.R
| with_text | R Documentation |
Generic function to filter issues with a given text pattern in the title, body, or comments of a GitHub Issue object or a collection of Issues.
with_text(x, ...)
## S3 method for class 'IssuesTB'
with_text(x, ..., in_title = TRUE, in_body = TRUE, in_comments = TRUE)
x |
An object of class |
... |
Additional arguments passed to |
in_title |
Boolean. Does the function search for text in the title?
(Default |
in_body |
Boolean. Does the function search for text in the body?
(Default |
in_comments |
Boolean. Does the function search for text in the
comments? (Default |
An object IssuesTB with issues that satisfy the condition.
all_issues <- get_issues(
source = "local",
dataset_dir = system.file("data_issues", package = "IssueTrackeR"),
dataset_name = "open_issues.yaml"
)
with_text(all_issues, pattern = "Excel")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.