Save datasets in a yaml file

write_to_dataset(
  x,
  dataset_dir = getOption("IssueTrackeR.dataset.dir"),
  dataset_name,
  overwrite = TRUE,
  verbose = TRUE,
  ...
)

# S3 method for class 'IssuesTB'
write_to_dataset(
  x,
  dataset_dir = getOption("IssueTrackeR.dataset.dir"),
  dataset_name = "list_issues.yaml",
  overwrite = TRUE,
  verbose = TRUE,
  ...
)

# S3 method for class 'LabelsTB'
write_to_dataset(
  x,
  dataset_dir = getOption("IssueTrackeR.dataset.dir"),
  dataset_name = "list_labels.yaml",
  overwrite = TRUE,
  verbose = TRUE,
  ...
)

# S3 method for class 'MilestonesTB'
write_to_dataset(
  x,
  dataset_dir = getOption("IssueTrackeR.dataset.dir"),
  dataset_name = "list_milestones.yaml",
  overwrite = TRUE,
  verbose = TRUE,
  ...
)

# Default S3 method
write_to_dataset(...)

Arguments

x

an object of class IssuesTB, LabelsTB or MilestonesTB.

dataset_dir

A character string specifying the path which contains the datasets (only taken into account if source is set to "local"). Defaults to the package option IssueTrackeR.dataset.dir.

dataset_name

A character string specifying the name of the datasets which will be written (only taken into account if source is set to "local"). Defaults to "open_issues.yaml".

overwrite

Boolean. If the dataset file already exists, should it be overwrite? Default is TRUE.

verbose

A logical value indicating whether to print additional information. Default is TRUE.

...

Unused parameter.

Value

invisibly (with invisible()) TRUE if the export was successful and an error otherwise.

Details

Depending on the object, the defaults value of the argument dataset_name (by default) is:

  • "list_issues.yaml" for issues;

  • "list_labels.yaml" for labels;

  • "list_milestones.yaml" for milestones.

Examples

path <- system.file("data_issues", package = "IssueTrackeR")
issues <- get_issues(
    source = "local",
    dataset_dir = path,
    dataset_name = "open_issues.yaml"
)
#> Looking into open_issues.yaml ...
#> The issues will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/open_issues.yaml.
milestones <- get_milestones(
    source = "local",
    dataset_dir = path,
    dataset_name = "list_milestones.yaml"
)
#> The milestones will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/list_milestones.yaml.
labels <- get_labels(
    source = "local",
    dataset_dir = path,
    dataset_name = "list_labels.yaml"
)
#> The labels will be read from /home/runner/work/_temp/Library/IssueTrackeR/data_issues/list_labels.yaml.

write_to_dataset(x = issues, dataset_dir = tempdir())
#> The datasets will be exported to /tmp/RtmpPIiKnp/list_issues.yaml.
write_to_dataset(x = labels, dataset_dir = tempdir())
#> The datasets will be exported to /tmp/RtmpPIiKnp/list_labels.yaml.
write_to_dataset(x = milestones, dataset_dir = tempdir())
#> The datasets will be exported to /tmp/RtmpPIiKnp/list_milestones.yaml.

write_to_dataset(x = issues, dataset_dir = tempdir(),
                 dataset_name = "my_issues")
#> The datasets will be exported to /tmp/RtmpPIiKnp/my_issues.yaml.
write_to_dataset(x = labels, dataset_dir = tempdir(),
                 dataset_name = "my_labels")
#> The datasets will be exported to /tmp/RtmpPIiKnp/my_labels.yaml.
write_to_dataset(x = milestones, dataset_dir = tempdir(),
                 dataset_name = "my_milestones")
#> The datasets will be exported to /tmp/RtmpPIiKnp/my_milestones.yaml.